<?php
    use AWeberWebFormPluginNamespace as AWeberWebformPluginAlias;
?>
    
<div class="aweber-wrapper">
    <form name="aweber_forms_import_form" class="aweber-advance-option-form" method="post" action="options.php">
        <?php wp_nonce_field('update-options'); ?>
        <input type="hidden" name="aweber_forms_import_hidden" value="Y">

        <?php
            settings_fields('AWeberWebformOauth');

            $pluginAdminOptions = get_option($this->adminOptionsName);
            $options = get_option($this->widgetOptionsName);

            $oauth_removed = get_option('aweber_webform_oauth_removed');
            $oauth_id = get_option('aweber_webform_oauth_id');

            $authorize_success = $changes_saved = False;
            $button_value = 'Connect';
            $error = $incorrect_oauth_id = null;
            $list = $account_id = null;

            // Check to see if they removed the connection
            $authorization_removed = False;
            if ($oauth_removed == 'TRUE' || (!empty($_GET['reauth']) && $_GET['reauth'] == True)) {
                $authorization_removed = True;
            }

            if ($authorization_removed) {
                $this->deauthorize();
                $pluginAdminOptions = get_option($this->adminOptionsName);
                $options = get_option($this->widgetOptionsName);
                $error = null;
            } else if ($oauth_id and !$pluginAdminOptions['access_secret']) {
                // Then they just saved a key and didn't remove anything
                // Check it's validity then save it for later use
                $error_code  = "";
                $exception_occured = False;
                $description = "Authorization code entered was: $oauth_id <br /> Please make sure you entered the complete authorization code and try again.";
                try {
                    list($consumer_key, $consumer_secret, $access_key, $access_secret) = AWeberWebformPluginAlias\AWeberAPI::getDataFromAweberID($oauth_id);
                } catch (AWeberWebformPluginAlias\AWeberAPIException $exc) {
                    list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
                    # make error messages customer friendly.
                    $description = preg_replace('/http.*$/i', '', $exc->getMessage());     # strip labs.aweber.com documentation url from error message
                    $error_code = $exc->status;
                    $exception_occured = True;
                } catch (AWeberWebformPluginAlias\AWeberOAuthDataMissing $exc) {
                    list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
                    $exception_occured = True;
                } catch (AWeberWebformPluginAlias\AWeberException $exc) {
                    list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
                    $exception_occured = True;
                // Catch the error that we were not expecting and show the Total Error.
                } catch (\Exception $exc) {
                    list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
                    list($exception_occured, $error) = True;
                    $description = $exc->getMessage();
                }

                if (!$access_secret) {
                    // Check the error is because of the In-correct authorization code was entered.
                    if (!$exception_occured || $error_code == '401') {
                        $incorrect_oauth_id = True;
                        update_option('aweber_webform_oauth_id', '');
                    } else {
                        $this->displayCustomErrorMessages($error_code, $description);
                        $this->deauthorize();
                    }
                } else {
                    $pluginAdminOptions = array(
                        'consumer_key' => $consumer_key,
                        'consumer_secret' => $consumer_secret,
                        'access_key' => $access_key,
                        'access_secret' => $access_secret,
                    );
                    update_option($this->adminOptionsName, $pluginAdminOptions);
                }
            }

            if (get_option('aweber_option_submitted') == 'TRUE') {
                if (get_option('aweber_comment_checkbox_toggle') == 'ON') {
                    if (get_option('aweber_comment_subscriber_listid') == 'FALSE') {
                        echo $this->messages['no_list_selected'];
                        $error = True;
                    }
                }

                if (get_option('aweber_registration_checkbox_toggle') == 'ON') {
                    if (get_option('aweber_register_subscriber_listid') == 'FALSE' && !$error) {
                        echo $this->messages['no_list_selected'];
                        $error = True;
                    }
                }
            
                // Update the widgetOptionsName row, Only if the Form is submitted and no error. 
                if (!$error) {
                    $options['create_subscriber_comment_checkbox'] = get_option('aweber_comment_checkbox_toggle');
                    $options['create_subscriber_registration_checkbox'] = get_option('aweber_registration_checkbox_toggle');
                    $options['aweber_add_analytics_checkbox'] = get_option('aweber_analytics_checkbox_toggle');
                    $options['aweber_register_subscriber_listid'] = get_option('aweber_register_subscriber_listid');
                    $options['aweber_comment_subscriber_listid'] = get_option('aweber_comment_subscriber_listid');
                    $options['aweber_comment_subscriber_tags'] = get_option('aweber_comment_subscriber_tags');
                    $options['aweber_register_subscriber_tags'] = get_option('aweber_register_subscriber_tags');
                        
                    if (get_option('aweber_comment_checkbox_toggle') == 'ON' && strlen(get_option('aweber_comment_subscriber_text')) < 7) {
                        echo $this->messages['signup_text_too_short'];
                    } else if (get_option('aweber_registration_checkbox_toggle') == 'ON' && strlen(get_option('aweber_register_subscriber_text')) < 7) {
                        echo $this->messages['signup_text_too_short'];
                    } else {
                        $options['aweber_comment_subscriber_text']  = get_option('aweber_comment_subscriber_text');
                        $options['aweber_register_subscriber_text'] = get_option('aweber_register_subscriber_text');
                    }
                    update_option($this->widgetOptionsName, $options);

                    $changes_saved = True;
                }
                
                // Update the Form submitted values as False.
                update_option('aweber_option_submitted', 'FALSE');
            }

            if ($pluginAdminOptions['access_key']) {
                extract($pluginAdminOptions);
                $error_ = null;
                $error_code = '';
                try {
                    $aweber = $this->_get_aweber_api($consumer_key, $consumer_secret);
                    $account = $aweber->getAccount($access_key, $access_secret);
                    
                    $lists = $account->lists;
                    $account_id = $account->id;

                    // API is called, just to make sure that the connection with the AWeber exists.
                    $sign_up_forms = $account->getWebForms();
                } catch (AWeberWebformPluginAlias\AWeberException $e) {
                    $error_ = get_class($e);
                    $error_code  = $e->status;
                    $description = $e->getMessage();
                    if (stripos($description, 'labs.aweber.com') !== false) {
                        $description = preg_replace('/http.*$/i', '', $description);  # strip labs.aweber.com documentation url from error message
                    }
                    $account = null;
                } catch (AWeberWebformPluginAlias\AWeberAPIException $e){
                    $description = $e->getMessage();
                    $error_code  = $e->status;
                    if (stripos($description, 'labs.aweber.com') !== false) {
                        $description = preg_replace('/http.*$/i', '', $description);  # strip labs.aweber.com documentation url from error message
                    }
                    $account = null;
                } catch (AWeberWebformPluginAlias\AWeberOAuthDataMissing $e){
                    $account = null;
                } catch (\Exception $exc) {
                    $description = $exc->getMessage();
                    $account = null;
                }

                if (!$account) {
                    $pluginAdminOptions = get_option($this->adminOptionsName);
                    $options = get_option($this->widgetOptionsName);
                    if($error_ != null && $error_ != 'AWeberWebFormPluginNamespace\AWeberOAuthException' && $error_ != 'AWeberWebFormPluginNamespace\AWeberOAuthDataMissing') {
                        $this->displayCustomErrorMessages($error_code, $description);
                    } else {
                        $error = True;
                        $this->displayCustomErrorMessages($error_code, $description);
                        $this->deauthorize();
                    }
                } else {
                    $authorize_success = True;
                    $button_value = 'Remove Connection';

                    /*  Update the Analytics URL in DB - If the user enables the 'Auto Add Analytics javascript' */
                    $options = get_option($this->widgetOptionsName);
                    if ($options['aweber_add_analytics_checkbox'] == 'ON') {
                        $options['aweber_analytics_src'] = $account->analytics_src;
                    } else {
                        $options['aweber_analytics_src'] = null;
                    }
                    update_option($this->widgetOptionsName, $options);
                }
            }
        ?>

        <div class="aweber-body-wrapper">
            <div class="aweber-body">

                <?php if(!$error): ?>
                    <ul class="list-inline">
                        <li class="<?php echo $authorize_success ? '' : 'active' ?>">
                            <a  href="javascript:void(0)" data-toggle="#connect">Connect</a>
                        </li>
                        <li class="<?php echo $authorize_success ? 'active' : '' ?>">
                            <a href="javascript:void(0)" class="<?php echo $authorize_success ? '' : 'disabled-tabs' ?>" data-toggle="#advance_opt">Advanced Options</a>
                        </li>
                        <li>
                            <a  href="javascript:void(0)" data-toggle="#system_info">System Info</a>
                        </li>
                    </ul>
                <?php endif; ?>

                <?php if (!$authorize_success): ?>
                    <p class="aweber-signup"> Don't have an AWeber account? 
                        <a target="_blank" type="button" href="https://aweber.com/order.htm?source=wordpressplugin" class="aweber-btn aweber-btn-success">Sign Up</a>
                    </p>
                <?php endif; ?>

                <div class="tab-content">
                    <!-- Connect Tab -->
                    <div id="connect" class="tab-pane <?php echo $authorize_success ? '' : 'active' ?>">
                        <?php if ($authorize_success): ?>
                            <!-- AWeber Authorization successful -->
                            <h1>Connected to AWeber</h1>
                            <p> 
                                You've successfully connected to your AWeber account! 
                                <br /><br />
                                <button type="button" class="aweber-btn aweber-btn-danger aweber-remove-connection-link">Remove Connection</button>
                            </p>
                        <?php elseif($error): ?>
                            <br><br>
                        <?php elseif(!empty(get_option('aweber_oauth_error'))): ?>
                            <label class="reauthorize-font">Please click here to reauthorize your account:</label><br/><br/>
                            <a class="aweber-btn aweber-btn-primary" type="button" href="/wp-admin/admin.php?page=aweber.php&amp;reauth=true">Reauthorize</a>
                        <?php else: ?>
                            <h1>Let's Get Started</h1>
                            <?php
                                if($authorization_removed):
                                    $this->add_alert_message_html('positive', 'You have successfully disconnected from your AWeber account.');
                                endif;
                            ?>

                            <table class="form-table">
                                <tr>
                                    <td><label>Step 1:</label></td>
                                    <td><a type="button" target="_blank" href="https://auth.aweber.com/1.0/oauth/authorize_app/f49b1bcf" class="aweber-btn aweber-btn-primary">Get Started</a></td>
                                </tr>
                                <tr>
                                    <td><label>Step 2:</label></td>
                                    <td>
                                        <label>Paste in your Authorization code:</label>
                                        <?php if($incorrect_oauth_id): ?>
                                            <input type="text" name="aweber_webform_oauth_id" class="aweber-form-text" value="<?php echo $oauth_id ?>" />
                                            <span class="aweber-error-message">An incorrect authorization code was entered.</span>
                                        <?php else: ?>
                                            <input type="text" name="aweber_webform_oauth_id" class="aweber-form-text" />
                                        <?php endif; ?>
                                    </td>
                                </tr>
                                <tr>
                                    <td colspan="3" align="right">
                                        <input type="hidden" name="_wp_http_referer" value="<?php echo admin_url('admin.php?page=aweber.php'); ?>" />
                                        <input type="submit" id="aweber-settings-button" class="aweber-btn aweber-btn-primary" value="Finish" />
                                    </td>
                                </tr>
                            </table>
                        <?php endif; ?>
                    </div>

                    <!-- Advanced Options -->
                    <div id="advance_opt" class="tab-pane <?php echo $authorize_success ? 'active' : '' ?>">
                        <?php if ($authorize_success): ?>
                            <h1>Advanced Options</h1>
                            <?php
                                $this->add_alert_message_html('negative', 'Please select any one subscriber list(s) to save the changes.', 'aweber-hide no-list-selected');
                                if($changes_saved):
                                    $this->add_alert_message_html('positive', 'Changes made to your subscriber list(s) saved successfuly.', 'list-changes-saved');
                                endif;
                            ?>

                            <!-- Sidebar Settings -->
                            <div class="aweber-widget-settings">
                                <h2> Widget Settings </h2>
                                <p>
                                    Go to the <a href="widgets.php">Widgets Page</a> and drag the AWeber widget into your widget area.
                                </p>
                            </div>

                            <div class="aweber-block-space"></div>

                            <!-- Commenting & New Registrations -->
                            <div class="aweber-advanced-options">
                                <h2> Commenting & New Registrations </h2>

                                <div class="aweber-fleft">
                                    <input type="checkbox" name="aweber_comment_checkbox" id="aweber-create-subscriber-comment-checkbox" 
                                    <?php echo ($options['create_subscriber_comment_checkbox'] == 'ON') ? 'checked="checked"' : ''; ?>  value="">
                                    <label for="aweber-create-subscriber-comment-checkbox">Add Subscribers when visitors leave a comment.</label>
                                    
                                    <div class="aweber-block-space"></div>

                                    <div style="margin-left: 20px">
                                        <label>Add Subscriber to:</label>
                                        <?php if (!empty($lists)): ?>
                                            <select class="aweber-form-text <?php echo $this->widgetOptionsName; ?>-comment-list">
                                                <option value="FALSE">Select A List</option>
                                                <?php foreach ($lists as $list): ?>
                                                    <option value="<?php echo $list->id; ?>"
                                                        <?php echo ($list->id == $options['aweber_comment_subscriber_listid']) ? ' selected="selected"' : ""; ?>>
                                                        <?php echo $list->name; ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        <?php else: ?>
                                            <p>This AWeber account does not currently have any lists.</p>
                                        <?php endif; ?>

                                        <div class="aweber-block-space"></div>

                                        <label>Add Tags:</label><small>(separate tags with commas)</small>
                                        <input type="text" placeholder="Add Tags" id="aweber-comment-subscriber-tags-input" value="<?php echo $options['aweber_comment_subscriber_tags'];?>" class="aweber-form-text" />

                                        <div class="aweber-block-space"></div>

                                        <label>Subscription Label:</label>
                                        <input type="text" placeholder="Subscription Label" id="aweber-comment-subscriber-input" value="<?php echo $options['aweber_comment_subscriber_text'];?>" class="aweber-form-text" />
                                    </div>
                                </div>
                                <?php if(wp_is_mobile()): ?>
                                    <div class="aweber-fleft" style="margin-top: 50px;">
                                <?php else:?>
                                    <div class="aweber-fleft" style="margin-left: 50px;">
                                <?php endif; ?>
                                
                                    <input type="checkbox" name="aweber_registration_checkbox" id="aweber-create-subscriber-registration-checkbox"
                                    <?php echo ($options['create_subscriber_registration_checkbox'] == 'ON') ? 'checked="checked"' : ''; ?> value="">
                                    <label for="aweber-create-subscriber-registration-checkbox">Add Subscribers when visitors register for your website.</label>

                                    <div class="aweber-block-space"></div>
                                    <div style="margin-left: 20px">
                                        <label>Add Subscriber to:</label>
                                        <?php if (!empty($lists)): ?>
                                            <select class="aweber-form-text <?php echo $this->widgetOptionsName; ?>-register-list">
                                                <option value="FALSE">Select A List</option>
                                                <?php foreach ($lists as $list): ?>
                                                    <option value="<?php echo $list->id; ?>"
                                                        <?php echo ($list->id == $options['aweber_register_subscriber_listid']) ? ' selected="selected"' : ""; ?>>
                                                        <?php echo $list->name; ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        <?php else: ?>
                                            <p>This AWeber account does not currently have any lists.</p>
                                        <?php endif; ?>

                                        <div class="aweber-block-space"></div>

                                        <label>Add Tags:</label><small>(separate tags with commas)</small>
                                        <input type="text" placeholder="Add Tags" id="aweber-register-subscriber-tags-input" value="<?php echo $options['aweber_register_subscriber_tags'];?>" class="aweber-form-text" />

                                        <div class="aweber-block-space"></div>

                                        <label>Subscription Label:</label>
                                        <input type="text" placeholder="Subscription Label" id="aweber-register-subscriber-input" value="<?php echo $options['aweber_register_subscriber_text'];?>" class="aweber-form-text" />
                                    </div>
                                </div>
                                <div style="clear: both;"></div>
                            </div>

                            <div class="aweber-block-space"></div>

                            <!-- Auto Add the Analytics JavaScript -->
                            <div class="aweber-event-tracking">
                                <h2> Analytics Event Tracking </h2>
                                <p>
                                    <input type="checkbox" id="aweber-add-analytics-checkbox" <?php echo $options['aweber_add_analytics_checkbox'] == 'ON' ? 'checked' : '' ?> >
                                    <label for="aweber-add-analytics-checkbox">Automatically add analytics JavaScript file to your website.</label>
                                </p>
                            </div>

                            <!-- Submit Button -->
                            <p class="submit" style="text-align: right;">
                                <input type="submit" id="aweber-settings-save-button" class="aweber-btn aweber-btn-success" value="Save" />
                            </p>

                            <!-- Hidden fields -->

                            <!-- Oauth Status field -->
                            <input type="hidden" id="aweber-settings-hidden-value" name="aweber_webform_oauth_removed" value="TRUE" />

                            <!-- Form Submitted status field -->
                            <input type="hidden" name="aweber_option_submitted" value="TRUE" />

                            <!-- AWeber Register Subscriber LIST ID -->
                            <input type="hidden" id="aweber-settings-hidden-register-subscriber-listid" 
                                name="aweber_register_subscriber_listid" value="<?php echo $options['aweber_register_subscriber_listid'];?>" />

                            <!-- AWeber Register Subscriber LIST ID -->
                            <input type="hidden" id="aweber-settings-hidden-comment-subscriber-listid" 
                                name="aweber_comment_subscriber_listid" value="<?php echo $options['aweber_comment_subscriber_listid'];?>" />

                            <!-- AWeber Comment subscriber status field -->
                            <input type="hidden" id="aweber-settings-hidden-comment-checkbox-value" 
                                name="aweber_comment_checkbox_toggle" value="<?php echo $options['create_subscriber_comment_checkbox'];?>" />

                            <!-- AWeber Register subscriber status field -->
                            <input type="hidden" id="aweber-settings-hidden-registration-checkbox-value" 
                                name="aweber_registration_checkbox_toggle" value="<?php echo $options['create_subscriber_registration_checkbox'];?>" />

                            <!-- AWeber Comment subscriber tag field -->
                            <input type="hidden" id="aweber-settings-hidden-comment-tags" 
                                name="aweber_comment_subscriber_tags" value="<?php echo $options['aweber_comment_subscriber_tags'];?>" />

                            <!-- AWeber Register subscriber tag field -->
                            <input type="hidden" id="aweber-settings-hidden-register-tags" 
                                name="aweber_register_subscriber_tags" value="<?php echo $options['aweber_register_subscriber_tags'];?>" />

                            <!-- AWeber Comment Subscriber signup text -->
                            <input type="hidden" id="aweber-settings-hidden-comment-text-value" 
                                name="aweber_comment_subscriber_text" value="<?php echo $options['aweber_comment_subscriber_text'];?>" />

                            <!-- AWeber Regsiter Subscriber signup text -->
                            <input type="hidden" id="aweber-settings-hidden-register-text-value" 
                                name="aweber_register_subscriber_text" value="<?php echo $options['aweber_register_subscriber_text'];?>" />

                            <!-- AWeber Analytics status field -->
                            <input type="hidden" id="aweber-settings-hidden-analytics-checkbox-toggle" 
                                name="aweber_analytics_checkbox_toggle" value="<?php echo $options['aweber_add_analytics_checkbox'];?>" />
                        <?php endif; ?>
                    </div>

                    <!-- System Info -->
                    <div id="system_info" class="tab-pane">
                        <?php
                            $this->add_alert_message_html('positive', '', 'aweber-hide');
                            $this->add_alert_message_html('negative', '', 'aweber-hide');
                        ?>
                        <h1>System Info</h1>
                        <table>
                            <tr>
                                <td><b>Home URL:</b></td>
                                <td><?php
                                    if (function_exists('get_home_url')):
                                        echo get_home_url();
                                    else:
                                        echo '-';
                                    endif;
                                    ?>
                                </td>
                            </tr>

                            <tr>
                                <td><b>Site URL:</b></td>
                                <td><?php
                                    if (function_exists('get_site_url')):
                                        echo get_home_url();
                                    else:
                                        echo '-';
                                    endif;
                                    ?>
                                </td>
                            </tr>

                            <tr>
                                <?php global $wp_version; ?>
                                <td><b>Wordpress Version:</b></td>
                                <td><?php echo isset($wp_version) ? $wp_version : '-' ?></td>
                            </tr>

                            <tr>
                                <td><b>PHP Version:</b></td>
                                <td><?php 
                                    if (function_exists('phpversion')):
                                        echo phpversion();
                                    else:
                                        echo '-';
                                    endif;
                                    ?>
                                </td>
                            </tr>

                            <tr>
                                <td><b>AWeber Account ID:</b></td>
                                <td><?php echo isset($account_id) ? $account_id : 'Not connected to AWeber' ?></td>
                            </tr>

                            <?php 
                                $plugin_path = join(DIRECTORY_SEPARATOR, array(dirname(__FILE__), '..', 'aweber.php'));
                                $plugin_data = get_plugin_data($plugin_path);
                                $plugin_version = $plugin_data['Version'];
                            ?>
                            <tr>
                                <td><b>AWeber Plugin Version:</b></td>
                                <td><?php echo $plugin_version; ?></td>
                            </tr>

                            <tr>
                                <td><b>Remote IP Address:</b></td>
                                <td><?php echo isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : '-' ?></td>
                            </tr>

                            <tr>
                                <td><b>X Forwarded For IPs:</b></td>
                                <td><?php echo isset($_SERVER['HTTP_X_FORWARDED_FOR']) ? $_SERVER['HTTP_X_FORWARDED_FOR'] : '-' ?></td>
                            </tr>

                            <tr>
                                <td><b>X Real IP:</b></td>
                                <td><?php echo isset($_SERVER['HTTP_X_REAL_IP']) ? $_SERVER['HTTP_X_REAL_IP'] : '-' ?></td>
                            </tr>
                        </table>

                        <br>

                        <button class="aweber-btn aweber-btn-primary" type="button" data-widget-name="<?php echo $this->widgetOptionsName ?>" id="aweber-webform-reload-cache">Reload Cache</button>

                    </div>

                </div>
            </div>
        </div>

        <div class="aweber-modal" id="show-remove-connection">
            <div class="aweber-modal-content aweber-modal-md">
                <div class="aweber-modal-header">
                    <h1>Disconnect from AWeber</h1>
                </div>
                <div class="aweber-modal-body">
                    <p>Are you sure you would like to disconnect from your AWeber account?</p>
                </div>
                <div class="aweber-modal-footer">
                    <button type="button" class="aweber-btn aweber-btn-plain aweber-dismiss-modal">Cancel</button>
                    <button class="aweber-btn aweber-btn-danger">Remove</button>
                </div>
            </div>
        </div>

        <input type="hidden" name="action" value="update" />        
        <input type="hidden" name="page_options" value="aweber_webform_oauth_id" />
    </form>

    <?php if ($authorization_removed or $authorize_success): ?>
        <script type="text/javascript" >
            jQuery.noConflict();
            jQuery(".aweber-admin-notice").hide();
        </script>
    <?php endif ?>
</div>
